@@ -41,11 +41,11 @@ class GSPeerConnectionBroadcasterPiCaller:
         self.camera = camera
         self.oncommand = oncommand
 
-    def startSocket(self):
-        GSPeerConnectionBroadcasterPiSocket.create(self.sio,
-                                                   self.gsdbs,
-                                                   self.camera,
-                                                   self.oncommand)
+    async def startSocket(self):
+        await GSPeerConnectionBroadcasterPiSocket.create(self.sio,
+                                                         self.gsdbs,
+                                                         self.camera,
+                                                         self.oncommand)
 
 
 class GSPeerConnectionBroadcasterPiSocket:
